@@ -1,7 +1,7 @@
 import typer
 
 import os, sys
-pwd = ".".join(__file__.split("/")[:-1])
+pwd = "/".join(__file__.split("/")[:-1])
 sys.path.append(pwd)
 os.system("export PYTHONPATH="+pwd)
 
